@@ -102,7 +102,7 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                 if response_token:
                     raise WsResponseError('Backend server didn\'t respond with a token')
 
-            request.META["CSRF_COOKIE_USED"] = True
+            request.META['CSRF_COOKIE_USED'] = True
 
             resp = HttpResponse(response_data, status=response.status, content_type='application/json', reason=response.reason)
             for header, value in response.getheaders():
@@ -112,9 +112,11 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                 resp[proxy_server.CSRF_TOKEN] = get_token(request)
 
             return resp
-        elif response.status:
-            if proxy_server.ERROR in response_data:
-                raise WsResponseError(response_json[proxy_server.ERROR][proxy_server.MESSAGE])
+        else:
+            if response.getheader('content-type', None) == 'application/json':
+                response_json = json.loads(response_data)
+                if proxy_server.ERROR in response_json:
+                    raise WsResponseError(response_json[proxy_server.ERROR][proxy_server.MESSAGE])
             else:
                 raise WsResponseError('Unknown error in backend server')
     else:
